@@ -227,6 +227,15 @@ def test_aqua_debian5_json():
         return json.loads(fp.read())
 
 
+@pytest.fixture
+def test_aqua_debian6_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-32091.json"
+    )
+    with open(test_cve_data, "r") as fp:
+        return json.loads(fp.read())
+
+
 def test_convert(test_cve_json):
     nvdlatest = NvdSource()
     data = nvdlatest.convert(test_cve_json)
@@ -349,6 +358,7 @@ def test_aqua_convert(
     test_aqua_debian3_json,
     test_aqua_debian4_json,
     test_aqua_debian5_json,
+    test_aqua_debian6_json,
 ):
     aqualatest = AquaSource()
     cve_data = aqualatest.convert(test_aqua_alsa_json)
@@ -390,3 +400,6 @@ def test_aqua_convert(
     cve_data = aqualatest.convert(test_aqua_debian5_json)
     assert cve_data
     assert len(cve_data) == 2
+    cve_data = aqualatest.convert(test_aqua_debian6_json)
+    assert cve_data
+    assert len(cve_data) == 2
