@@ -309,24 +309,41 @@ def test_os_build_compare1():
     assert res
     res = utils.version_compare("1:1.1.1k-7.el8_6", 0, "*", None, "1.1.1k")
     assert not res
-    # Not working
-    # res = utils.version_compare("1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1-1ubuntu2.1")
-    # assert not res
+    res = utils.version_compare("1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1-1ubuntu2.1")
+    assert not res
     res = utils.version_compare("0.23.22-1.amzn2.0.1", 0, "*", None, "0.23.22")
     assert not res
 
 
 def test_ubuntu_openssl():
-    # res = utils.version_compare("1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1.e")
-    # assert not res
-    # res = utils.version_compare(
-    #     "1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1-1ubuntu2.1~18.04.2"
-    # )
-    # assert not res
-    # res = utils.version_compare(
-    #     "1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1-1ubuntu2.1~18.04.6"
-    # )
-    # assert not res
+    res = utils.version_compare("1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1.e")
+    assert not res
+    res = utils.version_compare(
+        "1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1-1ubuntu2.1~18.04.2"
+    )
+    assert not res
+    res = utils.version_compare(
+        "1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1-1ubuntu2.1~18.04.6"
+    )
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", 0, "*", None, "1.1.1g-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", 0, "*", None, "1.1.1k-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", 0, "*", None, "1.1.1d-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", 0, "*", None, "1.1.1j-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", 0, "*", None, "1.1.1i-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", 0, "*", None, "1.1.1l-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", 0, "*", None, "1.1.1a-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", 0, "*", None, "1.1.1~~pre9-1")
+    assert not res
+    res = utils.version_compare("1.1.1n-0+deb11u3", 0, "*", None, "1.1.1o-1")
+    assert res
     res = utils.version_compare("1.10-0ubuntu4", 0, "*", None, "1.10-0ubuntu4.1")
     assert res
     res = utils.version_compare("2.2.19-3ubuntu2.1", 0, "*", None, "*")
