@@ -21,7 +21,7 @@ BASEVERSION = re.compile(
         (\.
         (?P<minor>0|[1-9]\d*)
         (\.
-            (?P<patch>0|[1-9]\d*)
+            (?P<patch>0|[1-9]\d*[a-zA-Z]?)
         )?
         (?:[-\.](?P<prerelease>
             (?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)
@@ -36,6 +36,7 @@ BASEVERSION = re.compile(
     re.VERBOSE,
 )
 
+
 KNOWN_PRERELEASE_STR = ["final", "release", "alpha", "beta", "rc", "latest"]
 
 DEBIAN_VALID_VERSION = re.compile(
@@ -288,10 +289,19 @@ def convert_to_semver(version):
     match = BASEVERSION.search(version)
     if not match:
         return (None, version)
-
     ver = {
         key: 0 if value is None else value for key, value in match.groupdict().items()
     }
+    # Trim patch
+    if ver.get("patch") and len(ver.get("patch")) > 1:
+        justnum = list(filter(str.isdigit, ver.get("patch")))
+        if justnum:
+            justnum = "".join(justnum)
+            if justnum and justnum != ver.get("patch"):
+                extrabits = ver.get("patch").replace(justnum, "")
+                if len(extrabits) == 1:
+                    ver["build"] = ord(extrabits)
+                ver["patch"] = int(justnum)
     # Trim based on known prerelease strings
     if ver.get("prerelease"):
         try:
@@ -668,7 +678,22 @@ def version_compare(
                 if is_max_exclude and not ubuntu_mode_detected
                 else max_value <= 0
             )
-            return min_check and max_check
+            ret_check = min_check and max_check
+            # openssl checks: 1.1.1n > 1.1.1g
+            if (
+                ret_check
+                and max_semver
+                and compare_semver.major == max_semver.major
+                and compare_semver.minor == max_semver.minor
+                and compare_semver.patch == max_semver.patch
+                and compare_semver.prerelease == max_semver.prerelease
+                and compare_semver.build != max_semver.build
+            ):
+                try:
+                    ret_check = int(compare_semver.build) < int(max_semver.build)
+                except Exception:
+                    pass
+            return ret_check
     compare_ver_build = None
     min_version_build = None
     max_version_build = None
